@@ -92,7 +92,7 @@ attrs = {'pet': {'units': 'mm timestep-1',
          'temp': {'units': 'C', 'long_name': 'air temperature',
                   'standard_name': 'air_temperature',
                   'missing_value': np.nan, 'fill_value': np.nan},
-         'vapor_pressure': {'units': 'kPa', 'long_name': 'vapor pressure',
+         'vapor_pressure': {'units': 'Pa', 'long_name': 'vapor pressure',
                             'standard_name': 'vapor_pressure',
                             'missing_value': np.nan, 'fill_value': np.nan},
          'air_pressure': {'units': 'kPa', 'long_name': 'air pressure',
